"use client";
import { usePathname, useRouter } from "@/i18n";
import { getToken } from "@/utils/Cookies";
import { Badge } from "antd-mobile";
import clsx from "clsx";
import { useTranslations } from "next-intl";
import { FC, ReactNode, useEffect, useState } from "react";
import "./style.scss";

/**
 * @description 底部Tab组件
 * @param children 插槽内容
 *
 */
export interface FooterProps {
    children?: ReactNode;
}

const tabList = [
    {
        iconSpanName: "icon-home",
        label: "start",
        path: "/",
    },
    {
        iconSpanName: "icon-qianbao1",
        label: "deposit",
        path: "/deposit",
    },
    {
        iconSpanName: "icon-afiliado",
        label: "affiliated",
        path: "/affiliate/summary",
    },
    {
        iconSpanName: "icon-tiyu",
        label: "exports",
        path: "/sports",
    },
    {
        iconSpanName: "icon-yonghu",
        label: "profile",
        path: "/profile",
    },
];
const Footer: FC = () => {
    const token = getToken();
    const t = useTranslations("navBar");

    const pathname = usePathname();
    const [tabActiveName, setTabActiveName] = useState("/");

    useEffect(() => {
        setTabActiveName(pathname);
    }, [pathname]);

    const router = useRouter();

    const goPage = (path = "/") => {
        if (!token && (path == "/deposit" || path == "/profile")) {
            router.push(`/login?redirect=${path}`);
            return;
        }
        setTabActiveName(path);
        router.push(path);
    };
    // const { data, run, cancel } = useRequest(, {
    //   pollingInterval: 3000,
    // });

    return (
        <footer className={"footer-placeholder"}>
            <div className="footer-box">
                <ul>
                    {tabList.map((item, index) => {
                        return (
                            <li
                                className={clsx(item.path == tabActiveName && "active")}
                                onClick={() => goPage(item.path)}
                                key={index}
                            >
                                <div className="icon-box">
                                    {index == 2 ? (
                                        <>
                                            <i className="icon-afiliado"></i>
                                            <i className="icon-rs"></i>
                                        </>
                                    ) : (
                                        <Badge content={index === 4 ? Badge.dot : null}>
                                            <span
                                                className={clsx("iconfont", item.iconSpanName)}
                                            ></span>
                                        </Badge>
                                    )}
                                    {index == 3 && <b className="icon-hot"></b>}
                                </div>
                                <label>{t(item.label)}</label>
                            </li>
                        );
                    })}
                </ul>
            </div>
        </footer>
    );
};

export default Footer;
